@@ -287,8 +287,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         self.oncommand = oncommand
         self.setChannel = setChannel
         # picam.append(camera)
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
 
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
@@ -345,6 +343,8 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             video = self.getPiH264Relay(id)
             audio = None
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
 
             transceiver = pc.addTransceiver("video", direction="sendonly")
 
@@ -393,9 +393,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 await pc.setLocalDescription(offer)
 
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
-            # asyncio.run(create_and_set_local_description(pc))
+            asyncio.run(create_and_set_local_description(pc))
+
+            # syncify_async_function(create_and_set_local_description(pc))
 
-            syncify_async_function(create_and_set_local_description(pc))
 
             self.sio.emit("watcher", {"target": description,
                                       "id": id,
